@@ -23,7 +23,7 @@
 #include <libgnome/gnome-macros.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <gtk/gtksignal.h>
 #include <gtk/gtkmain.h>
@@ -965,7 +965,8 @@ gnome_font_picker_dialog_destroy(GtkWidget *widget,
     gfp->_priv->font_dialog = NULL;
 } /* gnome_font_picker_dialog_destroy */
 
-GtkWidget *gnome_font_picker_create_inside(GnomeFontPicker *gfp)
+static GtkWidget *
+gnome_font_picker_create_inside(GnomeFontPicker *gfp)
 {
     GtkWidget *widget;
 
@@ -1017,7 +1018,7 @@ gnome_font_picker_label_use_font_in_label  (GnomeFontPicker *gfp)
 	gtk_widget_modify_font (gfp->_priv->font_label, desc);
 
 	pango_font_description_free (desc);
-	
+
 } /* gnome_font_picker_set_label_font */
 
 static void
